extras-buildsys/client archwelder.py, 1.2, 1.3 archwelder_config.py, 1.2, 1.3

Seth Vidal (skvidal) fedora-extras-commits at redhat.com
Sun Jun 5 07:05:29 UTC 2005


Author: skvidal

Update of /cvs/fedora/extras-buildsys/client
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv20371/client

Modified Files:
	archwelder.py archwelder_config.py 
Log Message:

put back changes to make it use mock, not mach.



Index: archwelder_config.py
===================================================================
RCS file: /cvs/fedora/extras-buildsys/client/archwelder_config.py,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- archwelder_config.py	4 Jun 2005 23:14:50 -0000	1.2
+++ archwelder_config.py	5 Jun 2005 07:05:23 -0000	1.3
@@ -1,7 +1,7 @@
 # Configuration file for archwelder.py
 
 config_opts = {}
-config_opts['mach_cmd'] = "/usr/bin/mach"
+config_opts['builder_cmd'] = "/usr/bin/mock"
 config_opts['distro_name'] = "fedora"
 config_opts['repo_name'] = "core"
 




More information about the fedora-extras-commits mailing list
Index: archwelder.py
===================================================================
RCS file: /cvs/fedora/extras-buildsys/client/archwelder.py,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- archwelder.py	4 Jun 2005 23:14:50 -0000	1.2
+++ archwelder.py	5 Jun 2005 07:05:23 -0000	1.3
@@ -114,33 +114,12 @@
         dl_thread = SRPMDownloadThread(self)
         dl_thread.start()
 
-    def _unlock(self):
-        print "%s: starting step 'unlocking'" % self._uniqid
-        cmd = '%s %s -r %s unlock' % (self.arch_command,
-                            CONFIG('mach_cmd'), self.buildroot)
-        self._pobj = popen2.Popen4(cmd=cmd)
-        self._status = 'unlocking'
-
-    def _clean(self):
-        print "%s: starting step 'cleaning'" % self._uniqid
-        cmd = '%s %s -r %s clean' % (self.arch_command,
-                            CONFIG('mach_cmd'), self.buildroot)
-        self._pobj = popen2.Popen4(cmd=cmd)
-        self._status = 'cleaning'
-        
-    
-    def _prep(self):
-        print "%s: starting step 'prepping'" % self._uniqid
-        cmd = '%s /%s -r %s setup prep' % (self.arch_command,
-                            CONFIG('mach_cmd'), self.buildroot)
-        self._pobj = popen2.Popen4(cmd=cmd)
-        self._status = 'prepping'
-        
     def _build(self):
         print "%s: starting step 'building'" % self._uniqid
-#??        os.chdir(self._mydir + '/' + self.buildarch)
-        cmd = '%s %s -r %s -c rebuild %s' % (self.arch_command,
-                            CONFIG('mach_cmd'), self.buildroot, self._srpm_path)
+        resultdir = CONFIG('built_rpm_download_basedir')
+        cmd = '%s %s -r %s --resultdir=%s %s' % (self.arch_command,
+                            CONFIG('builder_cmd'), self.buildroot, 
+                            resultdir, self._srpm_path)
         self._pobj = popen2.Popen4(cmd=cmd)
         self._status = 'building'
 
@@ -157,14 +136,9 @@
             else:
                 # If we're done with a step, advance to next one
                 exit_status = self._pobj.poll()
+                self._build()
                 if exit_status == 0:
-                    if self._status == 'unlocking':
-                        self._clean()
-                    elif self._status == 'cleaning':
-                        self._prep()
-                    elif self._status == 'prepping':
-                        self._build()
-                    elif self._status == 'building':
+                    if self._status == 'building':
                         # TODO: Should have 'moving' stage
                         # where files are copied to the directory
                         # that fileserver.py looks in.
@@ -176,7 +150,7 @@
                     print "%s: job failed!\n" % self._uniqid
                     self._status = 'failed'
                 else:
                     # mach process still running
                     pass
 
     def status(self):
@@ -176,7 +150,7 @@
                     self._status = 'failed'
                 else:
-                    # mach process still running
+                    # builder process still running
                     pass
 

